From f008adb5a77e094eaf6abf3fc0f36958e66896a5 Mon Sep 17 00:00:00 2001
From: tpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>
Date: Sat, 25 Jun 2011 05:28:35 +0000
Subject: TQt4 port koffice This should enable compilation under both Qt3 and
 Qt4; fixes for any missed components will be forthcoming

git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
---
 kplato/kpttask.h | 60 ++++++++++++++++++++++++++++----------------------------
 1 file changed, 30 insertions(+), 30 deletions(-)

(limited to 'kplato/kpttask.h')

diff --git a/kplato/kpttask.h b/kplato/kpttask.h
index 17972ee7..cace7dcb 100644
--- a/kplato/kpttask.h
+++ b/kplato/kpttask.h
@@ -25,7 +25,7 @@
 #include "kptduration.h"
 #include "kptresource.h"
 
-#include <qptrlist.h>
+#include <tqptrlist.h>
 
 namespace KPlato
 {
@@ -39,8 +39,8 @@ class DateTime;
   */
 class Task : public Node {
 public:
-    Task(Node *parent = 0);
-    Task(Task &task, Node *parent = 0);
+    Task(Node *tqparent = 0);
+    Task(Task &task, Node *tqparent = 0);
     ~Task();
 
     /// Return task type. Can be Type_Task, Type_Summarytask ot Type_Milestone.
@@ -80,53 +80,53 @@ public:
     void setConstraint(Node::ConstraintType type);
 
     /// Load from document
-    virtual bool load(QDomElement &element, Project &project);
+    virtual bool load(TQDomElement &element, Project &project);
     /// Save to document
-    virtual void save(QDomElement &element) const;
+    virtual void save(TQDomElement &element) const;
     /// Save appointments for schedule with id
-    virtual void saveAppointments(QDomElement &element, long id) const;
+    virtual void saveAppointments(TQDomElement &element, long id) const;
     /**
      * Returns a list of planned effort and cost for this task
      * for the interval start, end inclusive
      */
-    virtual EffortCostMap plannedEffortCostPrDay(const QDate &start, const QDate &end) const;
+    virtual EffortCostMap plannedEffortCostPrDay(const TQDate &start, const TQDate &end) const;
     
     /// Returns the total planned effort for this task (or subtasks) 
     virtual Duration plannedEffort();
     /// Returns the total planned effort for this task (or subtasks) on date
-    virtual Duration plannedEffort(const QDate &date);
+    virtual Duration plannedEffort(const TQDate &date);
     /// Returns the planned effort up to and including date
-    virtual Duration plannedEffortTo(const QDate &date);
+    virtual Duration plannedEffortTo(const TQDate &date);
     
     /// Returns the total actual effort for this task (or subtasks) 
     virtual Duration actualEffort();
     /// Returns the total actual effort for this task (or subtasks) on date
-    virtual Duration actualEffort(const QDate &date);
+    virtual Duration actualEffort(const TQDate &date);
     /// Returns the actual effort up to and including date
-    virtual Duration actualEffortTo(const QDate &date);
+    virtual Duration actualEffortTo(const TQDate &date);
     
     /**
      * Returns the total planned cost for this task (or subtasks)
      */
     virtual double plannedCost();
     /// Planned cost on date
-    virtual double plannedCost(const QDate &/*date*/);
+    virtual double plannedCost(const TQDate &/*date*/);
     /// Planned cost up to and including date
-    virtual double plannedCostTo(const QDate &/*date*/);
+    virtual double plannedCostTo(const TQDate &/*date*/);
     
     /**
      * Returns the actaually reported cost for this task (or subtasks)
      */
     virtual double actualCost();
     /// Actual cost on date
-    virtual double actualCost(const QDate &/*date*/);
+    virtual double actualCost(const TQDate &/*date*/);
     /// Actual cost up to and including date
-    virtual double actualCostTo(const QDate &/*date*/);
+    virtual double actualCostTo(const TQDate &/*date*/);
 
     /// Effort based performance index
-    double effortPerformanceIndex(const QDate &date, bool *error=0);
+    double effortPerformanceIndex(const TQDate &date, bool *error=0);
     /// Cost performance index
-    double costPerformanceIndex(const QDate &date, bool *error=0);
+    double costPerformanceIndex(const TQDate &date, bool *error=0);
     
     void initiateCalculation(Schedule &sch);
     /**
@@ -134,7 +134,7 @@ public:
      * This includes adding summarytasks relations to subtasks
      * and lists for start- and endnodes.
      */
-    void initiateCalculationLists(QPtrList<Node> &startnodes, QPtrList<Node> &endnodes, QPtrList<Node> &summarytasks);
+    void initiateCalculationLists(TQPtrList<Node> &startnodes, TQPtrList<Node> &endnodes, TQPtrList<Node> &summarytasks);
     /**
      * Calculates ref m_durationForward from ref earliestStart and
      * returns the resulting end time, 
@@ -186,14 +186,14 @@ public:
     // Proxy relations are relations to/from summarytasks. 
     // These relations are distrubuted to the relevant tasks before calculation.
     void clearProxyRelations();
-    void addParentProxyRelations(QPtrList<Relation> &list);
-    void addChildProxyRelations(QPtrList<Relation> &list);
+    void addParentProxyRelations(TQPtrList<Relation> &list);
+    void addChildProxyRelations(TQPtrList<Relation> &list);
     void addParentProxyRelation(Node *node, const Relation *rel);
     void addChildProxyRelation(Node *node, const Relation *rel);
     
     /// Check if this node has any dependent child nodes.
     bool isEndNode() const;
     /// Check if this node has any dependent parent nodes
     bool isStartNode() const;
     
     /**
@@ -244,7 +244,7 @@ public:
     /// Calculate critical path
     virtual bool calcCriticalPath(bool fromEnd);
     
     /// Set current schedule to schedule with identity id, for me nd my children
     virtual void setCurrentSchedule(long id);
     
     virtual bool effortMetError() const;
@@ -276,27 +276,27 @@ public:
     struct Progress &progress() { return m_progress; }
     
 private:
-    DateTime calculateSuccessors(const QPtrList<Relation> &list, int use);
-    DateTime calculatePredeccessors(const QPtrList<Relation> &list, int use);
-    DateTime scheduleSuccessors(const QPtrList<Relation> &list, int use);
-    DateTime schedulePredeccessors(const QPtrList<Relation> &list, int use);
+    DateTime calculateSuccessors(const TQPtrList<Relation> &list, int use);
+    DateTime calculatePredeccessors(const TQPtrList<Relation> &list, int use);
+    DateTime scheduleSuccessors(const TQPtrList<Relation> &list, int use);
+    DateTime schedulePredeccessors(const TQPtrList<Relation> &list, int use);
     
     DateTime workStartAfter(const DateTime &dt);
     DateTime workFinishBefore(const DateTime &dt);
 
 private:
-    QPtrList<ResourceGroup> m_resource;
+    TQPtrList<ResourceGroup> m_resource;
 
     ResourceRequestCollection *m_requests;
  
-    QPtrList<Relation> m_parentProxyRelations;
-    QPtrList<Relation> m_childProxyRelations;
+    TQPtrList<Relation> m_parentProxyRelations;
+    TQPtrList<Relation> m_childProxyRelations;
       
     struct Progress m_progress;
     
 #ifndef NDEBUG
 public:
-    void printDebug(bool children, QCString indent);
+    void printDebug(bool tqchildren, TQCString indent);
 #endif
 
 };
@@ -186,14 +186,14 @@ public:
     /// Check if this node has any dependent child nodes.
     bool isEndNode() const;
-    /// Check if this node has any dependent parent nodes
+    /// Check if this node has any dependent tqparent nodes
     bool isStartNode() const;
     
@@ -244,7 +244,7 @@ public:
     virtual bool calcCriticalPath(bool fromEnd);
     
-    /// Set current schedule to schedule with identity id, for me nd my children
+    /// Set current schedule to schedule with identity id, for me nd my tqchildren
     virtual void setCurrentSchedule(long id);
     
-- 
cgit v1.2.1